@@ -22,31 +22,31 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
-           '-DNDEBUG  -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-DNDEBUG    -fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
            '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
-           '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-           '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
-           '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-           '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv',
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -fexceptions '
+           '-g -grecord-gcc-switches -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
+           '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+           '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
+           '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-D_GNU_SOURCE -fPIC -fwrapv  -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+ 'CONFIGURE_CFLAGS': '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                      '-m64 -march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -89,7 +89,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-builtin-hashlib-hashes=blake2' '--with-valgrind' "
                 "'--without-ensurepip' '--enable-optimizations' "
                 "'build_alias=s390x-redhat-linux-gnu' "
-                "'host_alias=s390x-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
+                "'host_alias=s390x-redhat-linux-gnu' 'CC=gcc' 'CFLAGS=   "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                 '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
@@ -656,7 +656,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
         '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
@@ -695,7 +695,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -703,21 +703,21 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong   -m64 -march=z14 '
                              '-mtune=z15 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -O2  -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv -fexceptions -g -grecord-gcc-switches '
+                             '-pipe -Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=z14 '
                              '-mtune=z15 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -O2  -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv    -fexceptions -g -grecord-gcc-switches '
+                             '-pipe -Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=z14 '
                              '-mtune=z15 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -O2 -flto=auto -ffat-lto-objects '
+                             '-fwrapv  -O3 -flto=auto -ffat-lto-objects '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -734,10 +734,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -O2 -flto=auto '
-                             '-ffat-lto-objects -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
@@ -745,30 +745,30 @@ build_time_vars = {'ABIFLAGS': '',
                              '-m64 -march=z14 -mtune=z15 '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fno-semantic-interposition  '
+                             '-fwrapv -fno-semantic-interposition -O3 '
                              '-fprofile-use -fprofile-correction '
                              '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.9.19/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv',
- 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv  -O3',
+ 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -782,7 +782,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -791,27 +791,27 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                      '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                     '-fno-semantic-interposition  -fprofile-use '
+                     '-fno-semantic-interposition -O3 -fprofile-use '
                      '-fprofile-correction '
                      '-I/builddir/build/BUILD/Python-3.9.19/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions '
+                   '-g -grecord-gcc-switches -pipe -Wall '
+                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+                   '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv    '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
-                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-                   '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2 '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3 '
                    '-flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
@@ -825,7 +825,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -833,7 +833,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition  -fprofile-use '
+                   '-fno-semantic-interposition -O3 -fprofile-use '
                    '-fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
@@ -868,25 +868,25 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=z14 -mtune=z15 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=z14 -mtune=z15 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=z14 -mtune=z15 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -O2 -flto=auto '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -O3 -flto=auto '
                         '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -901,7 +901,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -910,7 +910,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                         '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                         '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition  -fprofile-use '
+                        '-fno-semantic-interposition -O3 -fprofile-use '
                         '-fprofile-correction '
                         '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
